@@ -1,32 +1,17 @@
-/** \file icons.h
-    \brief XPM info for the toolbar button icons
-    \ingroup gerbv
-*/
+#include <gdk-pixbuf/gdk-pixbuf.h>
 
-/* -------------------  Zoom tool icon  -------------------------- */
-/* GdkPixbuf RGBA C-Source image dump */
-#ifdef __SUNPRO_C
-#pragma align 4 (lzoom)
-#endif
-#ifdef __GNUC__
-static const guint8 lzoom[] __attribute__ ((__aligned__ (4))) = 
-#else
-static const guint8 lzoom[] = 
-#endif
+typedef struct icon {
+  GdkColorspace colorspace;
+  gboolean has_alpha;
+  int bits_per_sample;
+  int width;
+  int height;
+  int rowstride;
+  const guchar *data;
+} icon;
+
+static const guchar lzoom_data[] =
 { ""
-  /* Pixbuf magic (0x47646b50) */
-  "GdkP"
-  /* length: header (24) + pixel_data (2304) */
-  "\0\0\11\30"
-  /* pixdata_type (0x1010002) */
-  "\1\1\0\2"
-  /* rowstride (96) */
-  "\0\0\0`"
-  /* width (24) */
-  "\0\0\0\30"
-  /* height (24) */
-  "\0\0\0\30"
-  /* pixel_data: */
   "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0IIIN444\243---\335))"
   ")\373&&&\373&&&\335&&&\243555N\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
   "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
@@ -120,6 +105,15 @@ static const guint8 lzoom[] =
   "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
   "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"};
 
+static const icon lzoom = {
+  .colorspace = GDK_COLORSPACE_RGB,
+  .has_alpha = 1,
+  .bits_per_sample = 8,
+  .width = 24,
+  .height = 24,
+  .rowstride = 96,
+  .data = lzoom_data,
+};
 
 /* -------------------  Measure tool icon  ------------------- */
 /* GdkPixbuf RGBA C-Source image dump 1-byte-run-length-encoded */
@@ -128,135 +122,132 @@ static const guint8 lzoom[] =
    ver. 1.8.0-1~bpo70+.  This theme has been made by Rowen_Stipe based on
    Faenza and Faience icon themes by ~Tiheum. */
 
-#ifdef __SUNPRO_C
-#pragma align 4 (ruler)
-#endif
-#ifdef __GNUC__
-static const guint8 ruler[] __attribute__ ((__aligned__ (4))) = 
-#else
-static const guint8 ruler[] = 
-#endif
+static const guchar ruler_data[] =
 { ""
-  /* Pixbuf magic (0x47646b50) */
-  "GdkP"
-  /* length: header (24) + pixel_data (1689) */
-  "\0\0\6\261"
-  /* pixdata_type (0x2010002) */
-  "\2\1\0\2"
-  /* rowstride (96) */
-  "\0\0\0`"
-  /* width (24) */
-  "\0\0\0\30"
-  /* height (24) */
-  "\0\0\0\30"
-  /* pixel_data: */
-  "\233\377\377\377\0\1\0\0\0\7\220\0\0\0\15\1\0\0\0\7\205\377\377\377\0"
-  "\24\311\277e`\356\343\205\337\363\350\215\377\363\351\217\377\363\351"
-  "\222\377\363\351\225\377\364\352\227\377\364\352\231\377\364\353\233"
-  "\377\364\353\235\377\365\354\237\377\365\354\240\377\365\354\241\377"
-  "\365\355\244\377\365\355\246\377\366\355\250\377\366\356\252\377\366"
-  "\356\254\377\362\352\243\346\322\312~k\203\377\377\377\0\12\0\0\0\11"
-  "\352\335z\340\355\337_\377\357\342k\377\361\344z\377\360\344{\377\361"
-  "\345\201\377\361\346\201\377\361\347\205\377\362\347\205\377\202\362"
-  "\350\212\377\12\363\351\217\377\363\350\217\377\363\351\224\377\364\351"
-  "\223\377\364\352\230\377\364\352\227\377\364\353\231\377\364\353\236"
-  "\377\360\346\236\350\0\0\0\11\202\377\377\377\0\26\0\0\0\20\360\344{"
-  "\377\352\333L\377\357\343u\377\214|\"\377\361\345\200\377\214|$\377\361"
-  "\346\205\377\214|%\377\362\347\212\377\214}'\377\362\350\216\377\215"
-  "}(\377\363\351\223\377\215})\377\364\352\227\377\215~*\377\363\352\231"
-  "\377\215}*\377\363\352\231\377\365\355\244\377\0\0\0\20\202\377\377\377"
-  "\0\26\0\0\0\21\357\342u\377\353\331L\377\360\343v\377\206u\34\377\361"
-  "\345\202\377\206u\35\377\362\347\207\377\206v\36\377\362\350\214\377"
-  "\206v\40\377\362\350\220\377\206v\40\377\363\351\225\377\206v\"\377\363"
-  "\352\231\377\206v\"\377\364\352\232\377\206v\"\377\364\351\231\377\364"
-  "\353\240\377\0\0\0\21\202\377\377\377\0\26\0\0\0\22\356\340m\377\352"
-  "\330I\377\357\342u\377~m\26\377\361\345\201\377~m\27\377\361\345\206"
-  "\377\177m\30\377\361\346\213\377\177n\31\377\362\347\217\377\177n\32"
-  "\377\363\351\224\377\177n\32\377\363\351\230\377\177n\33\377\363\351"
-  "\232\377\177n\33\377\363\351\226\377\363\352\232\377\0\0\0\22\202\377"
-  "\377\377\0\26\0\0\0\24\355\337e\377\351\327E\377\356\341s\377xf\17\377"
-  "\360\344~\377xg\20\377\361\345\204\377xg\21\377\361\346\210\377xg\21"
-  "\377\361\346\215\377xg\22\377\362\350\221\377xg\22\377\363\351\225\377"
-  "xg\23\377\362\351\230\377xg\23\377\362\351\224\377\362\350\225\377\0"
-  "\0\0\24\202\377\377\377\0\26\0\0\0\25\352\334]\377\346\326@\377\355\340"
-  "o\377p_\11\377\356\343{\377p_\11\377\357\344\201\377p_\12\377\357\345"
-  "\205\377p_\12\377\360\346\211\377p_\12\377\361\346\215\377p_\13\377\361"
-  "\350\222\377p_\13\377\362\350\225\377p_\13\377\361\350\221\377\360\346"
-  "\216\377\0\0\0\25\202\377\377\377\0\26\0\0\0\26\351\332T\377\345\324"
-  ":\377\355\337k\377jW\3\377\356\341x\377jW\3\377\356\343}\377jW\3\377"
-  "\357\344\201\377jW\3\377\357\345\206\377jW\3\377\360\346\212\377jW\3"
-  "\377\361\347\217\377jW\3\377\361\350\221\377jW\3\377\361\346\215\377"
-  "\357\345\207\377\0\0\0\26\202\377\377\377\0\26\0\0\0\27\346\327J\377"
-  "\344\3226\377\353\335h\377fT\0\377\355\341t\377\355\341x\377\355\341"
-  "w\377\356\341}\377\356\342{\377\357\343\201\377\357\342\200\377\357\344"
-  "\205\377\357\345\207\377fT\0\377\360\346\214\377\360\345\215\377\360"
-  "\346\215\377\360\345\215\377\357\343\201\377\356\342\200\377\0\0\0\27"
-  "\202\377\377\377\0\26\0\0\0\30\345\325@\377\343\3201\377\352\335d\377"
-  "fT\0\377\354\340q\377\350\330Q\377\350\331T\377\351\332W\377\351\332"
-  "Z\377\351\332\\\377\352\333`\377\352\334b\377\357\344\205\377fT\0\377"
-  "\357\345\211\377\353\337n\377\354\337o\377\353\337l\377\353\336i\377"
-  "\355\340y\377\0\0\0\30\202\377\377\377\0\26\0\0\0\32\344\3228\377\343"
-  "\320-\377\352\334a\377fT\0\377\354\336n\377\347\327N\377\350\330Q\377"
-  "\350\331T\377\351\331W\377\351\332X\377\351\331V\377\350\330R\377\354"
-  "\337q\377fT\0\377\354\336o\377\347\326H\377\346\325C\377\345\3229\377"
-  "\343\3200\377\345\324A\377\0\0\0\32\202\377\377\377\0\12\0\0\0\33\343"
-  "\3200\377\342\316)\377\351\332]\377fT\0\377\353\335k\377\346\325I\377"
-  "\346\325H\377\345\324D\377\345\324@\377\203\345\323<\377\11\351\331W"
-  "\377\352\334c\377\351\331W\377\344\323;\377\344\3229\377\343\3200\377"
-  "\342\316'\377\343\3200\377\0\0\0\33\202\377\377\377\0\6\0\0\0\34\341"
-  "\315(\377\341\314#\377\351\331Z\377fT\0\377\351\333c\377\212\344\321"
-  ":\377\6\344\3219\377\343\3206\377\342\316.\377\341\314#\377\341\315("
-  "\377\0\0\0\34\202\377\377\377\0\1\0\0\0\35\202\337\313\37\377\3\346\327"
-  "U\377fT\0\377\350\331]\377\212\342\3206\377\3\342\3205\377\342\3172\377"
-  "\340\315*\377\202\337\313\37\377\1\0\0\0\35\202\377\377\377\0\6\0\0\0"
-  "\36\335\311\27\377\336\312\34\377\343\323E\377\347\330Y\377\345\326O"
-  "\377\212\341\3174\377\6\341\3173\377\341\3160\377\337\314'\377\336\312"
-  "\34\377\335\311\27\377\0\0\0\36\202\377\377\377\0\6\0\0\0\40\333\307"
-  "\20\377\335\311\30\377\336\313#\377\340\315+\377\340\316/\377\212\340"
-  "\3160\377\6\340\316/\377\340\315+\377\336\313#\377\335\311\30\377\333"
-  "\307\20\377\0\0\0\40\202\377\377\377\0\6\0\0\0!\332\305\15\377\333\306"
-  "\23\377\335\310\34\377\336\312%\377\337\313)\377\212\337\314+\377\6\337"
-  "\313)\377\336\312%\377\335\310\34\377\333\306\23\377\332\305\15\377\0"
-  "\0\0!\202\377\377\377\0\6\0\0\0\"\332\303\12\377\333\304\16\377\334\306"
-  "\25\377\335\307\32\377\335\310\36\377\212\336\311\40\377\6\335\310\36"
-  "\377\335\307\32\377\334\306\25\377\333\304\16\377\332\303\12\377\0\0"
-  "\0\"\202\377\377\377\0\7\0\0\0\40\272\247\10\353\331\303\12\377\332\303"
-  "\13\377\332\304\16\377\333\305\20\377\333\305\21\377\210\333\305\22\377"
-  "\7\333\305\21\377\333\305\20\377\332\304\16\377\332\303\13\377\331\303"
-  "\12\377\272\247\10\353\0\0\0\40\202\377\377\377\0\12\0\0\0\10QH\2\242"
-  "\274\251\20\355\334\307\35\377\334\311\"\377\335\312%\377\337\313)\377"
-  "\337\313,\377\337\314/\377\340\3153\377\202\340\3166\377\12\340\3153"
-  "\377\337\314/\377\337\313,\377\337\313)\377\335\312%\377\334\311\"\377"
-  "\334\307\35\377\274\251\20\355QH\2\242\0\0\0\10\203\377\377\377\0\3\0"
-  "\0\0+\0\0\0{\0\0\0\243\216\0\0\0\245\3\0\0\0\243\0\0\0{\0\0\0+\232\377"
-  "\377\377\0"};
+  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
+  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
+  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
+  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
+  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
+  "\377\377\377\0\377\377\377\0\0\0\0\7\0\0\0\15\0\0\0\15\0\0\0\15\0\0\0"
+  "\15\0\0\0\15\0\0\0\15\0\0\0\15\0\0\0\15\0\0\0\15\0\0\0\15\0\0\0\15\0\0"
+  "\0\15\0\0\0\15\0\0\0\15\0\0\0\15\0\0\0\15\0\0\0\7\377\377\377\0\377\377"
+  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\311\277e`\356\343\205"
+  "\337\363\350\215\377\363\351\217\377\363\351\222\377\363\351\225\377\364"
+  "\352\227\377\364\352\231\377\364\353\233\377\364\353\235\377\365\354\237"
+  "\377\365\354\240\377\365\354\241\377\365\355\244\377\365\355\246\377\366"
+  "\355\250\377\366\356\252\377\366\356\254\377\362\352\243\346\322\312~"
+  "k\377\377\377\0\377\377\377\0\377\377\377\0\0\0\0\11\352\335z\340\355"
+  "\337_\377\357\342k\377\361\344z\377\360\344{\377\361\345\201\377\361\346"
+  "\201\377\361\347\205\377\362\347\205\377\362\350\212\377\362\350\212\377"
+  "\363\351\217\377\363\350\217\377\363\351\224\377\364\351\223\377\364\352"
+  "\230\377\364\352\227\377\364\353\231\377\364\353\236\377\360\346\236\350"
+  "\0\0\0\11\377\377\377\0\377\377\377\0\0\0\0\20\360\344{\377\352\333L\377"
+  "\357\343u\377\214|\"\377\361\345\200\377\214|$\377\361\346\205\377\214"
+  "|%\377\362\347\212\377\214}'\377\362\350\216\377\215}(\377\363\351\223"
+  "\377\215})\377\364\352\227\377\215~*\377\363\352\231\377\215}*\377\363"
+  "\352\231\377\365\355\244\377\0\0\0\20\377\377\377\0\377\377\377\0\0\0"
+  "\0\21\357\342u\377\353\331L\377\360\343v\377\206u\34\377\361\345\202\377"
+  "\206u\35\377\362\347\207\377\206v\36\377\362\350\214\377\206v\40\377\362"
+  "\350\220\377\206v\40\377\363\351\225\377\206v\"\377\363\352\231\377\206"
+  "v\"\377\364\352\232\377\206v\"\377\364\351\231\377\364\353\240\377\0\0"
+  "\0\21\377\377\377\0\377\377\377\0\0\0\0\22\356\340m\377\352\330I\377\357"
+  "\342u\377~m\26\377\361\345\201\377~m\27\377\361\345\206\377\177m\30\377"
+  "\361\346\213\377\177n\31\377\362\347\217\377\177n\32\377\363\351\224\377"
+  "\177n\32\377\363\351\230\377\177n\33\377\363\351\232\377\177n\33\377\363"
+  "\351\226\377\363\352\232\377\0\0\0\22\377\377\377\0\377\377\377\0\0\0"
+  "\0\24\355\337e\377\351\327E\377\356\341s\377xf\17\377\360\344~\377xg\20"
+  "\377\361\345\204\377xg\21\377\361\346\210\377xg\21\377\361\346\215\377"
+  "xg\22\377\362\350\221\377xg\22\377\363\351\225\377xg\23\377\362\351\230"
+  "\377xg\23\377\362\351\224\377\362\350\225\377\0\0\0\24\377\377\377\0\377"
+  "\377\377\0\0\0\0\25\352\334]\377\346\326@\377\355\340o\377p_\11\377\356"
+  "\343{\377p_\11\377\357\344\201\377p_\12\377\357\345\205\377p_\12\377\360"
+  "\346\211\377p_\12\377\361\346\215\377p_\13\377\361\350\222\377p_\13\377"
+  "\362\350\225\377p_\13\377\361\350\221\377\360\346\216\377\0\0\0\25\377"
+  "\377\377\0\377\377\377\0\0\0\0\26\351\332T\377\345\324:\377\355\337k\377"
+  "jW\3\377\356\341x\377jW\3\377\356\343}\377jW\3\377\357\344\201\377jW\3"
+  "\377\357\345\206\377jW\3\377\360\346\212\377jW\3\377\361\347\217\377j"
+  "W\3\377\361\350\221\377jW\3\377\361\346\215\377\357\345\207\377\0\0\0"
+  "\26\377\377\377\0\377\377\377\0\0\0\0\27\346\327J\377\344\3226\377\353"
+  "\335h\377fT\0\377\355\341t\377\355\341x\377\355\341w\377\356\341}\377"
+  "\356\342{\377\357\343\201\377\357\342\200\377\357\344\205\377\357\345"
+  "\207\377fT\0\377\360\346\214\377\360\345\215\377\360\346\215\377\360\345"
+  "\215\377\357\343\201\377\356\342\200\377\0\0\0\27\377\377\377\0\377\377"
+  "\377\0\0\0\0\30\345\325@\377\343\3201\377\352\335d\377fT\0\377\354\340"
+  "q\377\350\330Q\377\350\331T\377\351\332W\377\351\332Z\377\351\332\\\377"
+  "\352\333`\377\352\334b\377\357\344\205\377fT\0\377\357\345\211\377\353"
+  "\337n\377\354\337o\377\353\337l\377\353\336i\377\355\340y\377\0\0\0\30"
+  "\377\377\377\0\377\377\377\0\0\0\0\32\344\3228\377\343\320-\377\352\334"
+  "a\377fT\0\377\354\336n\377\347\327N\377\350\330Q\377\350\331T\377\351"
+  "\331W\377\351\332X\377\351\331V\377\350\330R\377\354\337q\377fT\0\377"
+  "\354\336o\377\347\326H\377\346\325C\377\345\3229\377\343\3200\377\345"
+  "\324A\377\0\0\0\32\377\377\377\0\377\377\377\0\0\0\0\33\343\3200\377\342"
+  "\316)\377\351\332]\377fT\0\377\353\335k\377\346\325I\377\346\325H\377"
+  "\345\324D\377\345\324@\377\345\323<\377\345\323<\377\345\323<\377\351"
+  "\331W\377\352\334c\377\351\331W\377\344\323;\377\344\3229\377\343\320"
+  "0\377\342\316'\377\343\3200\377\0\0\0\33\377\377\377\0\377\377\377\0\0"
+  "\0\0\34\341\315(\377\341\314#\377\351\331Z\377fT\0\377\351\333c\377\344"
+  "\321:\377\344\321:\377\344\321:\377\344\321:\377\344\321:\377\344\321"
+  ":\377\344\321:\377\344\321:\377\344\321:\377\344\321:\377\344\3219\377"
+  "\343\3206\377\342\316.\377\341\314#\377\341\315(\377\0\0\0\34\377\377"
+  "\377\0\377\377\377\0\0\0\0\35\337\313\37\377\337\313\37\377\346\327U\377"
+  "fT\0\377\350\331]\377\342\3206\377\342\3206\377\342\3206\377\342\3206"
+  "\377\342\3206\377\342\3206\377\342\3206\377\342\3206\377\342\3206\377"
+  "\342\3206\377\342\3205\377\342\3172\377\340\315*\377\337\313\37\377\337"
+  "\313\37\377\0\0\0\35\377\377\377\0\377\377\377\0\0\0\0\36\335\311\27\377"
+  "\336\312\34\377\343\323E\377\347\330Y\377\345\326O\377\341\3174\377\341"
+  "\3174\377\341\3174\377\341\3174\377\341\3174\377\341\3174\377\341\317"
+  "4\377\341\3174\377\341\3174\377\341\3174\377\341\3173\377\341\3160\377"
+  "\337\314'\377\336\312\34\377\335\311\27\377\0\0\0\36\377\377\377\0\377"
+  "\377\377\0\0\0\0\40\333\307\20\377\335\311\30\377\336\313#\377\340\315"
+  "+\377\340\316/\377\340\3160\377\340\3160\377\340\3160\377\340\3160\377"
+  "\340\3160\377\340\3160\377\340\3160\377\340\3160\377\340\3160\377\340"
+  "\3160\377\340\316/\377\340\315+\377\336\313#\377\335\311\30\377\333\307"
+  "\20\377\0\0\0\40\377\377\377\0\377\377\377\0\0\0\0!\332\305\15\377\333"
+  "\306\23\377\335\310\34\377\336\312%\377\337\313)\377\337\314+\377\337"
+  "\314+\377\337\314+\377\337\314+\377\337\314+\377\337\314+\377\337\314"
+  "+\377\337\314+\377\337\314+\377\337\314+\377\337\313)\377\336\312%\377"
+  "\335\310\34\377\333\306\23\377\332\305\15\377\0\0\0!\377\377\377\0\377"
+  "\377\377\0\0\0\0\"\332\303\12\377\333\304\16\377\334\306\25\377\335\307"
+  "\32\377\335\310\36\377\336\311\40\377\336\311\40\377\336\311\40\377\336"
+  "\311\40\377\336\311\40\377\336\311\40\377\336\311\40\377\336\311\40\377"
+  "\336\311\40\377\336\311\40\377\335\310\36\377\335\307\32\377\334\306\25"
+  "\377\333\304\16\377\332\303\12\377\0\0\0\"\377\377\377\0\377\377\377\0"
+  "\0\0\0\40\272\247\10\353\331\303\12\377\332\303\13\377\332\304\16\377"
+  "\333\305\20\377\333\305\21\377\333\305\22\377\333\305\22\377\333\305\22"
+  "\377\333\305\22\377\333\305\22\377\333\305\22\377\333\305\22\377\333\305"
+  "\22\377\333\305\21\377\333\305\20\377\332\304\16\377\332\303\13\377\331"
+  "\303\12\377\272\247\10\353\0\0\0\40\377\377\377\0\377\377\377\0\0\0\0"
+  "\10QH\2\242\274\251\20\355\334\307\35\377\334\311\"\377\335\312%\377\337"
+  "\313)\377\337\313,\377\337\314/\377\340\3153\377\340\3166\377\340\316"
+  "6\377\340\3153\377\337\314/\377\337\313,\377\337\313)\377\335\312%\377"
+  "\334\311\"\377\334\307\35\377\274\251\20\355QH\2\242\0\0\0\10\377\377"
+  "\377\0\377\377\377\0\377\377\377\0\0\0\0+\0\0\0{\0\0\0\243\0\0\0\245\0"
+  "\0\0\245\0\0\0\245\0\0\0\245\0\0\0\245\0\0\0\245\0\0\0\245\0\0\0\245\0"
+  "\0\0\245\0\0\0\245\0\0\0\245\0\0\0\245\0\0\0\245\0\0\0\245\0\0\0\243\0"
+  "\0\0{\0\0\0+\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
+  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
+  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
+  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
+  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
+  "\377\377\0\377\377\377\0"};
+
+static const icon ruler = {
+  .colorspace = GDK_COLORSPACE_RGB,
+  .has_alpha = 1,
+  .bits_per_sample = 8,
+  .width = 24,
+  .height = 24,
+  .rowstride = 96,
+  .data = ruler_data,
+};
 
 
 /* -------------------  Move tool icon  -------------------------- */
 /* GdkPixbuf RGBA C-Source image dump */
 
-#ifdef __SUNPRO_C
-#pragma align 4 (move)
-#endif
-#ifdef __GNUC__
-static const guint8 move[] __attribute__ ((__aligned__ (4))) = 
-#else
-static const guint8 move[] = 
-#endif
+static const guchar move_data[] =
 { ""
-  /* Pixbuf magic (0x47646b50) */
-  "GdkP"
-  /* length: header (24) + pixel_data (1936) */
-  "\0\0\7\250"
-  /* pixdata_type (0x1010002) */
-  "\1\1\0\2"
-  /* rowstride (88) */
-  "\0\0\0X"
-  /* width (22) */
-  "\0\0\0\26"
-  /* height (22) */
-  "\0\0\0\26"
-  /* pixel_data: */
   "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
   "\0\0\0\0\0\0\40J\207\31\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
   "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
@@ -324,32 +315,21 @@ static const guint8 move[] =
   "\0\0\0\2\0\0\0\2\0\0\0\3\0\0\0\3\0\0\0\2\0\0\0\2\0\0\0\1\0\0\0\1\0\0"
   "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"};
 
+static const icon move = {
+  .colorspace = GDK_COLORSPACE_RGB,
+  .has_alpha = 1,
+  .bits_per_sample = 8,
+  .width = 22,
+  .height = 22,
+  .rowstride = 88,
+  .data = move_data,
+};
 
 /* -------------------  Pointer tool icon  -------------------------- */
 /* GdkPixbuf RGBA C-Source image dump */
 
-#ifdef __SUNPRO_C
-#pragma align 4 (pointer)
-#endif
-#ifdef __GNUC__
-static const guint8 pointer[] __attribute__ ((__aligned__ (4))) = 
-#else
-static const guint8 pointer[] = 
-#endif
+static const guchar pointer_data[] =
 { ""
-  /* Pixbuf magic (0x47646b50) */
-  "GdkP"
-  /* length: header (24) + pixel_data (2304) */
-  "\0\0\11\30"
-  /* pixdata_type (0x1010002) */
-  "\1\1\0\2"
-  /* rowstride (96) */
-  "\0\0\0`"
-  /* width (24) */
-  "\0\0\0\30"
-  /* height (24) */
-  "\0\0\0\30"
-  /* pixel_data: */
   "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
   "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
   "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
@@ -464,4 +444,12 @@ static const guint8 pointer[] =
   "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
   "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"};
 
-
+static const icon pointer = {
+  .colorspace = GDK_COLORSPACE_RGB,
+  .has_alpha = 1,
+  .bits_per_sample = 8,
+  .width = 24,
+  .height = 24,
+  .rowstride = 96,
+  .data = pointer_data,
+};
